==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebRowToggleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowToggleEventArgsDetailDescriptionMetadata } from "./WebRowToggleEventArgsDetailDescriptionMetadata";
import { WebRowToggleEventArgsDescription } from "./WebRowToggleEventArgsDescription";
/**
 * @hidden
 */
export let WebRowToggleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowToggleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowToggleEventArgsDescriptionMetadata.a == null) {
                WebRowToggleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowToggleEventArgsDescriptionMetadata.c(WebRowToggleEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebRowToggleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRowToggleEventArgsDescriptionMetadata.a);
            WebRowToggleEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowToggleEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebRowToggleEventArgsDetail");
        }
        static d(a) {
            WebRowToggleEventArgsDescriptionMetadata.b(a);
            a.aa("WebRowToggleEventArgs", () => new WebRowToggleEventArgsDescription());
            a.z("WebRowToggleEventArgs", WebRowToggleEventArgsDescriptionMetadata.a);
        }
    }
    WebRowToggleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowToggleEventArgsDescriptionMetadata, 'WebRowToggleEventArgsDescriptionMetadata');
    WebRowToggleEventArgsDescriptionMetadata.a = null;
    return WebRowToggleEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRowToggleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowToggleEventArgsDetailDescriptionMetadata } from "./WebRowToggleEventArgsDetailDescriptionMetadata";
import { WebRowToggleEventArgsDescription } from "./WebRowToggleEventArgsDescription";
/**
 * @hidden
 */
export let WebRowToggleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowToggleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowToggleEventArgsDescriptionMetadata.a == null) {
                WebRowToggleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowToggleEventArgsDescriptionMetadata.c(WebRowToggleEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebRowToggleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRowToggleEventArgsDescriptionMetadata.a);
            WebRowToggleEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowToggleEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebRowToggleEventArgsDetail");
        }
        static d(a) {
            WebRowToggleEventArgsDescriptionMetadata.b(a);
            a.ac("WebRowToggleEventArgs", () => new WebRowToggleEventArgsDescription());
            a.ab("WebRowToggleEventArgs", WebRowToggleEventArgsDescriptionMetadata.a);
        }
    }
    WebRowToggleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowToggleEventArgsDescriptionMetadata, 'WebRowToggleEventArgsDescriptionMetadata');
    WebRowToggleEventArgsDescriptionMetadata.a = null;
    return WebRowToggleEventArgsDescriptionMetadata;
})();
